@@ -1,12 +1,12 @@
-from pathlib import Path
 import sys
+from pathlib import Path
 
 if sys.version_info < (3, 9):
     import importlib_resources
 else:
     import importlib.resources as importlib_resources
 
-from asdf.resource import DirectoryResourceMapping
+from asdf_standard import DirectoryResourceMapping
 
 import asdf_transform_schemas
 
